@@ -11,21 +11,21 @@ use predicates::str::PredicateStrExt;
 use predicates_core;
 use predicates_tree::CaseTreeExt;
 
-use errors::dump_buffer;
-use errors::output_fmt;
+use cmd::dump_buffer;
+use cmd::output_fmt;
 
 /// Assert the state of an [`Output`].
 ///
 /// # Examples
 ///
-/// ```rust
+/// ```rust,no_run
 /// use assert_cmd::prelude::*;
 ///
 /// use std::process::Command;
 ///
-/// Command::main_binary()
-///     .unwrap()
-///     .assert()
+/// let mut cmd = Command::cargo_bin("bin_fixture")
+///     .unwrap();
+/// cmd.assert()
 ///     .success();
 /// ```
 ///
@@ -35,14 +35,14 @@ pub trait OutputAssertExt {
     ///
     /// # Examples
     ///
-    /// ```rust
+    /// ```rust,no_run
     /// use assert_cmd::prelude::*;
     ///
     /// use std::process::Command;
     ///
-    /// Command::main_binary()
-    ///     .unwrap()
-    ///     .assert()
+    /// let mut cmd = Command::cargo_bin("bin_fixture")
+    ///     .unwrap();
+    /// cmd.assert()
     ///     .success();
     /// ```
     ///
@@ -69,14 +69,14 @@ impl<'c> OutputAssertExt for &'c mut process::Command {
 ///
 /// # Examples
 ///
-/// ```rust
+/// ```rust,no_run
 /// use assert_cmd::prelude::*;
 ///
 /// use std::process::Command;
 ///
-/// Command::main_binary()
-///     .unwrap()
-///     .assert()
+/// let mut cmd = Command::cargo_bin("bin_fixture")
+///     .unwrap();
+/// cmd.assert()
 ///     .success();
 /// ```
 ///
@@ -102,12 +102,12 @@ impl Assert {
     ///
     /// # Examples
     ///
-    /// ```rust
+    /// ```rust,no_run
     /// use assert_cmd::prelude::*;
     ///
     /// use std::process::Command;
     ///
-    /// Command::main_binary()
+    /// Command::cargo_bin("bin_fixture")
     ///     .unwrap()
     ///     .assert()
     ///     .append_context("main", "no args")
@@ -132,12 +132,12 @@ impl Assert {
     ///
     /// # Examples
     ///
-    /// ```rust
+    /// ```rust,no_run
     /// use assert_cmd::prelude::*;
     ///
     /// use std::process::Command;
     ///
-    /// Command::main_binary()
+    /// Command::cargo_bin("bin_fixture")
     ///     .unwrap()
     ///     .assert()
     ///     .success();
@@ -165,12 +165,12 @@ impl Assert {
     ///
     /// # Examples
     ///
-    /// ```rust
+    /// ```rust,no_run
     /// use assert_cmd::prelude::*;
     ///
     /// use std::process::Command;
     ///
-    /// Command::main_binary()
+    /// Command::cargo_bin("bin_fixture")
     ///     .unwrap()
     ///     .env("exit", "1")
     ///     .assert()
@@ -193,32 +193,56 @@ impl Assert {
 
     /// Ensure the command returned the expected code.
     ///
+    /// This uses [`IntoCodePredicate`] to provide short-hands for common cases.
+    ///
+    /// See [`predicates`] for more predicates.
+    ///
     /// # Examples
     ///
-    /// ```rust,ignore
+    /// Accepting a predicate:
+    /// ```rust,no_run
+    /// extern crate assert_cmd;
+    /// extern crate predicates;
+    ///
     /// use assert_cmd::prelude::*;
     ///
     /// use std::process::Command;
     /// use predicates::prelude::*;
     ///
-    /// Command::main_binary()
+    /// Command::cargo_bin("bin_fixture")
     ///     .unwrap()
     ///     .env("exit", "42")
     ///     .assert()
     ///     .code(predicate::eq(42));
+    /// ```
     ///
-    /// // which can be shortened to:
-    /// Command::main_binary()
+    /// Accepting an exit code:
+    /// ```rust,no_run
+    /// use assert_cmd::prelude::*;
+    ///
+    /// use std::process::Command;
+    ///
+    /// Command::cargo_bin("bin_fixture")
     ///     .unwrap()
     ///     .env("exit", "42")
     ///     .assert()
     ///     .code(42);
     /// ```
     ///
-    /// - See [`predicates::prelude`] for more predicates.
-    /// - See [`IntoCodePredicate`] for other built-in conversions.
+    /// Accepting multiple exit codes:
+    /// ```rust,no_run
+    /// use assert_cmd::prelude::*;
     ///
-    /// [`predicates::prelude`]: https://docs.rs/predicates/0.9.0/predicates/prelude
+    /// use std::process::Command;
+    ///
+    /// Command::cargo_bin("bin_fixture")
+    ///     .unwrap()
+    ///     .env("exit", "42")
+    ///     .assert()
+    ///     .code(&[2, 42] as &[i32]);
+    /// ```
+    ///
+    /// [`predicates`]: https://docs.rs/predicates
     /// [`IntoCodePredicate`]: trait.IntoCodePredicate.html
     pub fn code<I, P>(self, pred: I) -> Self
     where
@@ -229,7 +253,8 @@ impl Assert {
     }
 
     fn code_impl(self, pred: &predicates_core::Predicate<i32>) -> Self {
-        let actual_code = self.output
+        let actual_code = self
+            .output
             .status
             .code()
             .unwrap_or_else(|| panic!("Command interrupted\n{}", self));
@@ -241,23 +266,69 @@ impl Assert {
 
     /// Ensure the command wrote the expected data to `stdout`.
     ///
+    /// This uses [`IntoOutputPredicate`] to provide short-hands for common cases.
+    ///
+    /// See [`predicates`] for more predicates.
+    ///
     /// # Examples
     ///
-    /// ```rust,ignore
+    /// Accepting a bytes predicate:
+    /// ```rust,no_run
+    /// extern crate assert_cmd;
+    /// extern crate predicates;
+    ///
     /// use assert_cmd::prelude::*;
     ///
     /// use std::process::Command;
     /// use predicates::prelude::*;
     ///
-    /// Command::main_binary()
+    /// Command::cargo_bin("bin_fixture")
     ///     .unwrap()
     ///     .env("stdout", "hello")
     ///     .env("stderr", "world")
     ///     .assert()
-    ///     .stdout(predicate::str::similar("hello\n").from_utf8());
+    ///     .stdout(predicate::eq(b"hello\n" as &[u8]));
+    /// ```
     ///
-    /// // which can be shortened to:
-    /// Command::main_binary()
+    /// Accepting a `str` predicate:
+    /// ```rust,no_run
+    /// extern crate assert_cmd;
+    /// extern crate predicates;
+    ///
+    /// use assert_cmd::prelude::*;
+    ///
+    /// use std::process::Command;
+    /// use predicates::prelude::*;
+    ///
+    /// Command::cargo_bin("bin_fixture")
+    ///     .unwrap()
+    ///     .env("stdout", "hello")
+    ///     .env("stderr", "world")
+    ///     .assert()
+    ///     .stdout(predicate::str::similar("hello\n"));
+    /// ```
+    ///
+    /// Accepting bytes:
+    /// ```rust,no_run
+    /// use assert_cmd::prelude::*;
+    ///
+    /// use std::process::Command;
+    ///
+    /// Command::cargo_bin("bin_fixture")
+    ///     .unwrap()
+    ///     .env("stdout", "hello")
+    ///     .env("stderr", "world")
+    ///     .assert()
+    ///     .stdout(b"hello\n" as &[u8]);
+    /// ```
+    ///
+    /// Accepting a `str`:
+    /// ```rust,no_run
+    /// use assert_cmd::prelude::*;
+    ///
+    /// use std::process::Command;
+    ///
+    /// Command::cargo_bin("bin_fixture")
     ///     .unwrap()
     ///     .env("stdout", "hello")
     ///     .env("stderr", "world")
@@ -265,10 +336,7 @@ impl Assert {
     ///     .stdout("hello\n");
     /// ```
     ///
-    /// - See [`predicates::prelude`] for more predicates.
-    /// - See [`IntoOutputPredicate`] for other built-in conversions.
-    ///
-    /// [`predicates::prelude`]: https://docs.rs/predicates/0.9.0/predicates/prelude
+    /// [`predicates`]: https://docs.rs/predicates
     /// [`IntoOutputPredicate`]: trait.IntoOutputPredicate.html
     pub fn stdout<I, P>(self, pred: I) -> Self
     where
@@ -290,23 +358,69 @@ impl Assert {
 
     /// Ensure the command wrote the expected data to `stderr`.
     ///
+    /// This uses [`IntoOutputPredicate`] to provide short-hands for common cases.
+    ///
+    /// See [`predicates`] for more predicates.
+    ///
     /// # Examples
     ///
-    /// ```rust,ignore
+    /// Accepting a bytes predicate:
+    /// ```rust,no_run
+    /// extern crate assert_cmd;
+    /// extern crate predicates;
+    ///
     /// use assert_cmd::prelude::*;
     ///
     /// use std::process::Command;
     /// use predicates::prelude::*;
     ///
-    /// Command::main_binary()
+    /// Command::cargo_bin("bin_fixture")
     ///     .unwrap()
     ///     .env("stdout", "hello")
     ///     .env("stderr", "world")
     ///     .assert()
-    ///     .stderr(predicate::str::similar("world\n").from_utf8());
+    ///     .stderr(predicate::eq(b"world\n" as &[u8]));
+    /// ```
     ///
-    /// // which can be shortened to:
-    /// Command::main_binary()
+    /// Accepting a `str` predicate:
+    /// ```rust,no_run
+    /// extern crate assert_cmd;
+    /// extern crate predicates;
+    ///
+    /// use assert_cmd::prelude::*;
+    ///
+    /// use std::process::Command;
+    /// use predicates::prelude::*;
+    ///
+    /// Command::cargo_bin("bin_fixture")
+    ///     .unwrap()
+    ///     .env("stdout", "hello")
+    ///     .env("stderr", "world")
+    ///     .assert()
+    ///     .stderr(predicate::str::similar("world\n"));
+    /// ```
+    ///
+    /// Accepting bytes:
+    /// ```rust,no_run
+    /// use assert_cmd::prelude::*;
+    ///
+    /// use std::process::Command;
+    ///
+    /// Command::cargo_bin("bin_fixture")
+    ///     .unwrap()
+    ///     .env("stdout", "hello")
+    ///     .env("stderr", "world")
+    ///     .assert()
+    ///     .stderr(b"world\n" as &[u8]);
+    /// ```
+    ///
+    /// Accepting a `str`:
+    /// ```rust,no_run
+    /// use assert_cmd::prelude::*;
+    ///
+    /// use std::process::Command;
+    ///
+    /// Command::cargo_bin("bin_fixture")
     ///     .unwrap()
     ///     .env("stdout", "hello")
     ///     .env("stderr", "world")
@@ -314,10 +428,7 @@ impl Assert {
     ///     .stderr("world\n");
     /// ```
     ///
-    /// - See [`predicates::prelude`] for more predicates.
-    /// - See [`IntoOutputPredicate`] for other built-in conversions.
-    ///
-    /// [`predicates::prelude`]: https://docs.rs/predicates/0.9.0/predicates/prelude
+    /// [`predicates`]: https://docs.rs/predicates
     /// [`IntoOutputPredicate`]: trait.IntoOutputPredicate.html
     pub fn stderr<I, P>(self, pred: I) -> Self
     where
@@ -360,20 +471,23 @@ impl fmt::Debug for Assert {
 ///
 /// # Examples
 ///
-/// ```rust,ignore
+/// ```rust,no_run
+/// extern crate assert_cmd;
+/// extern crate predicates;
+///
 /// use assert_cmd::prelude::*;
 ///
 /// use std::process::Command;
 /// use predicates::prelude::*;
 ///
-/// Command::main_binary()
+/// Command::cargo_bin("bin_fixture")
 ///     .unwrap()
 ///     .env("exit", "42")
 ///     .assert()
 ///     .code(predicate::eq(42));
 ///
 /// // which can be shortened to:
-/// Command::main_binary()
+/// Command::cargo_bin("bin_fixture")
 ///     .unwrap()
 ///     .env("exit", "42")
 ///     .assert()
@@ -381,7 +495,7 @@ impl fmt::Debug for Assert {
 /// ```
 ///
 /// [`Assert::code`]: struct.Assert.html#method.code
-/// [`Predicate<i32>`]: https://docs.rs/predicates-core/0.9.0/predicates_core/trait.Predicate.html
+/// [`Predicate<i32>`]: https://docs.rs/predicates-core/1.0.0/predicates_core/trait.Predicate.html
 pub trait IntoCodePredicate<P>
 where
     P: predicates_core::Predicate<i32>,
@@ -404,27 +518,151 @@ where
     }
 }
 
-impl IntoCodePredicate<predicates::ord::EqPredicate<i32>> for i32 {
-    type Predicate = predicates::ord::EqPredicate<i32>;
+// Keep `predicates` concrete Predicates out of our public API.
+/// [Predicate] used by [`IntoCodePredicate`] for code.
+///
+/// # Example
+///
+/// ```rust,no_run
+/// use assert_cmd::prelude::*;
+///
+/// use std::process::Command;
+///
+/// Command::cargo_bin("bin_fixture")
+///     .unwrap()
+///     .env("exit", "42")
+///     .assert()
+///     .code(42);
+/// ```
+///
+/// [`IntoCodePredicate`]: trait.IntoCodePredicate.html
+/// [Predicate]: https://docs.rs/predicates-core/1.0.0/predicates_core/trait.Predicate.html
+#[derive(Debug)]
+pub struct EqCodePredicate(predicates::ord::EqPredicate<i32>);
 
-    fn into_code(self) -> Self::Predicate {
-        predicates::ord::eq(self)
+impl EqCodePredicate {
+    pub(crate) fn new(value: i32) -> Self {
+        let pred = predicates::ord::eq(value);
+        EqCodePredicate(pred)
     }
 }
 
-impl IntoCodePredicate<predicates::iter::InPredicate<i32>> for Vec<i32> {
-    type Predicate = predicates::iter::InPredicate<i32>;
+impl predicates_core::reflection::PredicateReflection for EqCodePredicate {
+    fn parameters<'a>(
+        &'a self,
+    ) -> Box<Iterator<Item = predicates_core::reflection::Parameter<'a>> + 'a> {
+        self.0.parameters()
+    }
 
-    fn into_code(self) -> Self::Predicate {
-        predicates::iter::in_iter(self)
+    /// Nested `Predicate`s of the current `Predicate`.
+    fn children<'a>(&'a self) -> Box<Iterator<Item = predicates_core::reflection::Child<'a>> + 'a> {
+        self.0.children()
     }
 }
 
-impl IntoCodePredicate<predicates::iter::InPredicate<i32>> for &'static [i32] {
-    type Predicate = predicates::iter::InPredicate<i32>;
+impl predicates_core::Predicate<i32> for EqCodePredicate {
+    fn eval(&self, item: &i32) -> bool {
+        self.0.eval(item)
+    }
+
+    fn find_case<'a>(
+        &'a self,
+        expected: bool,
+        variable: &i32,
+    ) -> Option<predicates_core::reflection::Case<'a>> {
+        self.0.find_case(expected, variable)
+    }
+}
+
+impl fmt::Display for EqCodePredicate {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        self.0.fmt(f)
+    }
+}
+
+impl IntoCodePredicate<EqCodePredicate> for i32 {
+    type Predicate = EqCodePredicate;
 
     fn into_code(self) -> Self::Predicate {
-        predicates::iter::in_iter(self.iter().cloned())
+        Self::Predicate::new(self)
+    }
+}
+
+// Keep `predicates` concrete Predicates out of our public API.
+/// [Predicate] used by [`IntoCodePredicate`] for iterables of codes.
+///
+/// # Example
+///
+/// ```rust,no_run
+/// use assert_cmd::prelude::*;
+///
+/// use std::process::Command;
+///
+/// Command::cargo_bin("bin_fixture")
+///     .unwrap()
+///     .env("exit", "42")
+///     .assert()
+///     .code(&[2, 42] as &[i32]);
+/// ```
+///
+/// [`IntoCodePredicate`]: trait.IntoCodePredicate.html
+/// [Predicate]: https://docs.rs/predicates-core/1.0.0/predicates_core/trait.Predicate.html
+#[derive(Debug)]
+pub struct InCodePredicate(predicates::iter::InPredicate<i32>);
+
+impl InCodePredicate {
+    pub(crate) fn new<I: IntoIterator<Item = i32>>(value: I) -> Self {
+        let pred = predicates::iter::in_iter(value);
+        InCodePredicate(pred)
+    }
+}
+
+impl predicates_core::reflection::PredicateReflection for InCodePredicate {
+    fn parameters<'a>(
+        &'a self,
+    ) -> Box<Iterator<Item = predicates_core::reflection::Parameter<'a>> + 'a> {
+        self.0.parameters()
+    }
+
+    /// Nested `Predicate`s of the current `Predicate`.
+    fn children<'a>(&'a self) -> Box<Iterator<Item = predicates_core::reflection::Child<'a>> + 'a> {
+        self.0.children()
+    }
+}
+
+impl predicates_core::Predicate<i32> for InCodePredicate {
+    fn eval(&self, item: &i32) -> bool {
+        self.0.eval(item)
+    }
+
+    fn find_case<'a>(
+        &'a self,
+        expected: bool,
+        variable: &i32,
+    ) -> Option<predicates_core::reflection::Case<'a>> {
+        self.0.find_case(expected, variable)
+    }
+}
+
+impl fmt::Display for InCodePredicate {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        self.0.fmt(f)
+    }
+}
+
+impl IntoCodePredicate<InCodePredicate> for Vec<i32> {
+    type Predicate = InCodePredicate;
+
+    fn into_code(self) -> Self::Predicate {
+        Self::Predicate::new(self)
+    }
+}
+
+impl IntoCodePredicate<InCodePredicate> for &'static [i32] {
+    type Predicate = InCodePredicate;
+
+    fn into_code(self) -> Self::Predicate {
+        Self::Predicate::new(self.iter().cloned())
     }
 }
 
@@ -433,13 +671,16 @@ impl IntoCodePredicate<predicates::iter::InPredicate<i32>> for &'static [i32] {
 ///
 /// # Examples
 ///
-/// ```rust,ignore
+/// ```rust,no_run
+/// extern crate assert_cmd;
+/// extern crate predicates;
+///
 /// use assert_cmd::prelude::*;
 ///
 /// use std::process::Command;
 /// use predicates::prelude::*;
 ///
-/// Command::main_binary()
+/// Command::cargo_bin("bin_fixture")
 ///     .unwrap()
 ///     .env("stdout", "hello")
 ///     .env("stderr", "world")
@@ -447,7 +688,7 @@ impl IntoCodePredicate<predicates::iter::InPredicate<i32>> for &'static [i32] {
 ///     .stdout(predicate::str::similar("hello\n").from_utf8());
 ///
 /// // which can be shortened to:
-/// Command::main_binary()
+/// Command::cargo_bin("bin_fixture")
 ///     .unwrap()
 ///     .env("stdout", "hello")
 ///     .env("stderr", "world")
@@ -457,7 +698,7 @@ impl IntoCodePredicate<predicates::iter::InPredicate<i32>> for &'static [i32] {
 ///
 /// [`Assert::stdout`]: struct.Assert.html#method.stdout
 /// [`Assert::stderr`]: struct.Assert.html#method.stderr
-/// [`Predicate<[u8]>`]: https://docs.rs/predicates-core/0.9.0/predicates_core/trait.Predicate.html
+/// [`Predicate<[u8]>`]: https://docs.rs/predicates-core/1.0.0/predicates_core/trait.Predicate.html
 pub trait IntoOutputPredicate<P>
 where
     P: predicates_core::Predicate<[u8]>,
@@ -483,8 +724,23 @@ where
 // Keep `predicates` concrete Predicates out of our public API.
 /// [Predicate] used by [`IntoOutputPredicate`] for bytes.
 ///
+/// # Example
+///
+/// ```rust,no_run
+/// use assert_cmd::prelude::*;
+///
+/// use std::process::Command;
+///
+/// Command::cargo_bin("bin_fixture")
+///     .unwrap()
+///     .env("stdout", "hello")
+///     .env("stderr", "world")
+///     .assert()
+///     .stderr(b"world\n" as &[u8]);
+/// ```
+///
 /// [`IntoOutputPredicate`]: trait.IntoOutputPredicate.html
-/// [Predicate]: https://docs.rs/predicates-core/0.9.0/predicates_core/trait.Predicate.html
+/// [Predicate]: https://docs.rs/predicates-core/1.0.0/predicates_core/trait.Predicate.html
 #[derive(Debug)]
 pub struct BytesContentOutputPredicate(predicates::ord::EqPredicate<&'static [u8]>);
 
@@ -539,8 +795,23 @@ impl IntoOutputPredicate<BytesContentOutputPredicate> for &'static [u8] {
 // Keep `predicates` concrete Predicates out of our public API.
 /// [Predicate] used by [`IntoOutputPredicate`] for [`str`].
 ///
+/// # Example
+///
+/// ```rust,no_run
+/// use assert_cmd::prelude::*;
+///
+/// use std::process::Command;
+///
+/// Command::cargo_bin("bin_fixture")
+///     .unwrap()
+///     .env("stdout", "hello")
+///     .env("stderr", "world")
+///     .assert()
+///     .stderr("world\n");
+/// ```
+///
 /// [`IntoOutputPredicate`]: trait.IntoOutputPredicate.html
-/// [Predicate]: https://docs.rs/predicates-core/0.9.0/predicates_core/trait.Predicate.html
+/// [Predicate]: https://docs.rs/predicates-core/1.0.0/predicates_core/trait.Predicate.html
 /// [`str`]: https://doc.rust-lang.org/std/primitive.str.html
 #[derive(Debug, Clone)]
 pub struct StrContentOutputPredicate(
@@ -548,7 +819,12 @@ pub struct StrContentOutputPredicate(
 );
 
 impl StrContentOutputPredicate {
-    pub(crate) fn new(value: &'static str) -> Self {
+    pub(crate) fn from_str(value: &'static str) -> Self {
+        let pred = predicates::str::similar(value).from_utf8();
+        StrContentOutputPredicate(pred)
+    }
+
+    pub(crate) fn from_string(value: String) -> Self {
         let pred = predicates::str::similar(value).from_utf8();
         StrContentOutputPredicate(pred)
     }
@@ -587,9 +863,109 @@ impl fmt::Display for StrContentOutputPredicate {
     }
 }
 
+impl IntoOutputPredicate<StrContentOutputPredicate> for String {
+    type Predicate = StrContentOutputPredicate;
+
+    fn into_output(self) -> Self::Predicate {
+        Self::Predicate::from_string(self)
+    }
+}
+
 impl IntoOutputPredicate<StrContentOutputPredicate> for &'static str {
     type Predicate = StrContentOutputPredicate;
 
+    fn into_output(self) -> Self::Predicate {
+        Self::Predicate::from_str(self)
+    }
+}
+
+// Keep `predicates` concrete Predicates out of our public API.
+/// [Predicate] used by [`IntoOutputPredicate`] for [`Predicate<str>`].
+///
+/// # Example
+///
+/// ```rust,no_run
+/// extern crate assert_cmd;
+/// extern crate predicates;
+///
+/// use assert_cmd::prelude::*;
+///
+/// use std::process::Command;
+/// use predicates::prelude::*;
+///
+/// Command::cargo_bin("bin_fixture")
+///     .unwrap()
+///     .env("stdout", "hello")
+///     .env("stderr", "world")
+///     .assert()
+///     .stderr(predicate::str::similar("world\n"));
+/// ```
+///
+/// [`IntoOutputPredicate`]: trait.IntoOutputPredicate.html
+/// [Predicate]: https://docs.rs/predicates-core/1.0.0/predicates_core/trait.Predicate.html
+#[derive(Debug, Clone)]
+pub struct StrOutputPredicate<P: predicates_core::Predicate<str>>(
+    predicates::str::Utf8Predicate<P>,
+);
+
+impl<P> StrOutputPredicate<P>
+where
+    P: predicates_core::Predicate<str>,
+{
+    pub(crate) fn new(pred: P) -> Self {
+        let pred = pred.from_utf8();
+        StrOutputPredicate(pred)
+    }
+}
+
+impl<P> predicates_core::reflection::PredicateReflection for StrOutputPredicate<P>
+where
+    P: predicates_core::Predicate<str>,
+{
+    fn parameters<'a>(
+        &'a self,
+    ) -> Box<Iterator<Item = predicates_core::reflection::Parameter<'a>> + 'a> {
+        self.0.parameters()
+    }
+
+    /// Nested `Predicate`s of the current `Predicate`.
+    fn children<'a>(&'a self) -> Box<Iterator<Item = predicates_core::reflection::Child<'a>> + 'a> {
+        self.0.children()
+    }
+}
+
+impl<P> predicates_core::Predicate<[u8]> for StrOutputPredicate<P>
+where
+    P: predicates_core::Predicate<str>,
+{
+    fn eval(&self, item: &[u8]) -> bool {
+        self.0.eval(item)
+    }
+
+    fn find_case<'a>(
+        &'a self,
+        expected: bool,
+        variable: &[u8],
+    ) -> Option<predicates_core::reflection::Case<'a>> {
+        self.0.find_case(expected, variable)
+    }
+}
+
+impl<P> fmt::Display for StrOutputPredicate<P>
+where
+    P: predicates_core::Predicate<str>,
+{
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        self.0.fmt(f)
+    }
+}
+
+impl<P> IntoOutputPredicate<StrOutputPredicate<P>> for P
+where
+    P: predicates_core::Predicate<str>,
+{
+    type Predicate = StrOutputPredicate<P>;
+
     fn into_output(self) -> Self::Predicate {
         Self::Predicate::new(self)
     }
